@@ -1,17 +1,10 @@
 /*
- *
- * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
- *           (C) 2009 Gustavo Pichorim Boiko <gustavo.boiko@kdemail.net>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2009 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 2003 Sebastian Trueg <trueg@k3b.org>
+    SPDX-FileCopyrightText: 2009 Gustavo Pichorim Boiko <gustavo.boiko@kdemail.net>
+    SPDX-FileCopyrightText: 1998-2009 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 
 #include "k3bmovixdoc.h"
@@ -468,4 +461,4 @@ bool K3b::MovixDoc::saveDocumentData( QDomElement* docElem )
     return true;
 }
 
-
+#include "moc_k3bmovixdoc.cpp"
