@@ -40,11 +40,7 @@ namespace K3b {
     private:
         void init();
         bool event( QEvent* event ) override;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        void enterEvent( QEvent* event ) override;
-#else
         void enterEvent( QEnterEvent* event ) override;
-#endif
         void leaveEvent( QEvent* event ) override;
         void paintEvent( QPaintEvent* event ) override;
         void setHover( bool );
